pub struct UnwrapForCall {
pub sender: Address,
pub token_address: Address,
pub amount: U256,
}Expand description
Container type for all input parameters for the unwrapFor function with signature unwrapFor(address,address,uint256) and selector 0x261c80b6
Fields
sender: Addresstoken_address: Addressamount: U256Trait Implementations
Sourceimpl AbiDecode for UnwrapForCall
impl AbiDecode for UnwrapForCall
Sourceimpl AbiEncode for UnwrapForCall
impl AbiEncode for UnwrapForCall
Sourceimpl AbiType for UnwrapForCall
impl AbiType for UnwrapForCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for UnwrapForCall
impl Clone for UnwrapForCall
Sourcefn clone(&self) -> UnwrapForCall
fn clone(&self) -> UnwrapForCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnwrapForCall
impl Debug for UnwrapForCall
Sourceimpl Default for UnwrapForCall
impl Default for UnwrapForCall
Sourcefn default() -> UnwrapForCall
fn default() -> UnwrapForCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UnwrapForCall
impl<'de> Deserialize<'de> for UnwrapForCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for UnwrapForCall
impl Display for UnwrapForCall
Sourceimpl EthCall for UnwrapForCall
impl EthCall for UnwrapForCall
Sourceimpl From<UnwrapForCall> for TokenWrapperContractCalls
impl From<UnwrapForCall> for TokenWrapperContractCalls
Sourcefn from(value: UnwrapForCall) -> Self
fn from(value: UnwrapForCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for UnwrapForCall
impl Hash for UnwrapForCall
Sourceimpl PartialEq for UnwrapForCall
impl PartialEq for UnwrapForCall
Sourceimpl Serialize for UnwrapForCall
impl Serialize for UnwrapForCall
Sourceimpl Tokenizable for UnwrapForCall
impl Tokenizable for UnwrapForCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for UnwrapForCall
impl Eq for UnwrapForCall
impl StructuralPartialEq for UnwrapForCall
impl TokenizableItem for UnwrapForCall